@@ -1,6 +1,4 @@
 #include "cheapr_cpp.h"
-#include <cpp11.hpp>
-#include <Rinternals.h>
 
 // Basic math operations by reference
 // All NA and NaN values are ignored
@@ -32,12 +30,12 @@ SEXP cpp_set_abs(SEXP x){
     if (n_cores > 1){
       OMP_PARALLEL_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] != NA_INTEGER) p_x[i] = std::abs(p_x[i]);
+        p_x[i] = p_x[i] == NA_INTEGER ? p_x[i] : std::abs(p_x[i]);
       }
     } else {
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] != NA_INTEGER) p_x[i] = std::abs(p_x[i]);
+        p_x[i] = p_x[i] == NA_INTEGER ? p_x[i] : std::abs(p_x[i]);
       }
     }
     break;
@@ -47,13 +45,13 @@ SEXP cpp_set_abs(SEXP x){
     if (n_cores > 1){
       OMP_PARALLEL_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::fabs(p_x[i]);
+        p_x[i] = p_x[i] != p_x[i] ? p_x[i] : std::fabs(p_x[i]);
       }
     }
     else {
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::fabs(p_x[i]);
+        p_x[i] = p_x[i] != p_x[i] ? p_x[i] : std::fabs(p_x[i]);
       }
     }
     break;
@@ -72,12 +70,12 @@ SEXP cpp_set_floor(SEXP x){
     if (n_cores > 1){
       OMP_PARALLEL_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::floor(p_x[i]);
+        p_x[i] = (p_x[i] == p_x[i]) ? std::floor(p_x[i]) : p_x[i];
       }
     } else {
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::floor(p_x[i]);
+        p_x[i] = (p_x[i] == p_x[i]) ? std::floor(p_x[i]) : p_x[i];
       }
     }
   }
@@ -94,12 +92,12 @@ SEXP cpp_set_ceiling(SEXP x){
     if (n_cores > 1){
       OMP_PARALLEL_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::ceil(p_x[i]);
+        p_x[i] = (p_x[i] == p_x[i]) ? std::ceil(p_x[i]) : p_x[i];
       }
     } else {
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::ceil(p_x[i]);
+        p_x[i] = (p_x[i] == p_x[i]) ? std::ceil(p_x[i]) : p_x[i];
       }
     }
   }
@@ -116,12 +114,12 @@ SEXP cpp_set_trunc(SEXP x){
     if (n_cores > 1){
       OMP_PARALLEL_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::trunc(p_x[i]);
+        p_x[i] = (p_x[i] == p_x[i]) ? std::trunc(p_x[i]) : p_x[i];
       }
     } else {
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = std::trunc(p_x[i]);
+        p_x[i] = (p_x[i] == p_x[i]) ? std::trunc(p_x[i]) : p_x[i];
       }
     }
   }
@@ -139,12 +137,12 @@ SEXP cpp_set_change_sign(SEXP x){
     if (n_cores > 1){
       OMP_PARALLEL_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] != NA_INTEGER) p_x[i] = -p_x[i];
+        p_x[i] = (p_x[i] == NA_INTEGER) ? p_x[i] : -p_x[i];
       }
     } else {
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] != NA_INTEGER) p_x[i] = -p_x[i];
+        p_x[i] = (p_x[i] == NA_INTEGER) ? p_x[i] : -p_x[i];
       }
     }
     break;
@@ -155,12 +153,12 @@ SEXP cpp_set_change_sign(SEXP x){
       int n_cores = num_cores();
       OMP_PARALLEL_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = -p_x[i];
+        p_x[i] = (p_x[i] == p_x[i]) ? -p_x[i] : p_x[i];
       }
     } else {
       OMP_FOR_SIMD
       for (R_xlen_t i = 0; i < n; ++i) {
-        if (p_x[i] == p_x[i]) p_x[i] = -p_x[i];
+        p_x[i] = (p_x[i] == p_x[i]) ? -p_x[i] : p_x[i];
       }
     }
     break;
@@ -180,12 +178,12 @@ SEXP cpp_set_exp(SEXP x){
   if (n_cores > 1){
     OMP_PARALLEL_FOR_SIMD
     for (R_xlen_t i = 0; i < n; ++i) {
-      if (p_x[i] == p_x[i]) p_x[i] = std::exp(p_x[i]);
+      p_x[i] = (p_x[i] == p_x[i]) ? std::exp(p_x[i]) : p_x[i];
     }
   } else {
     OMP_FOR_SIMD
     for (R_xlen_t i = 0; i < n; ++i) {
-      if (p_x[i] == p_x[i]) p_x[i] = std::exp(p_x[i]);
+      p_x[i] = (p_x[i] == p_x[i]) ? std::exp(p_x[i]) : p_x[i];
     }
   }
   Rf_unprotect(1);
@@ -203,12 +201,12 @@ SEXP cpp_set_sqrt(SEXP x){
   if (n_cores > 1){
     OMP_PARALLEL_FOR_SIMD
     for (R_xlen_t i = 0; i < n; ++i) {
-      if (p_x[i] == p_x[i]) p_x[i] = std::sqrt(p_x[i]);
+      p_x[i] = (p_x[i] == p_x[i]) ? std::sqrt(p_x[i]) : p_x[i];
     }
   } else {
     OMP_FOR_SIMD
     for (R_xlen_t i = 0; i < n; ++i) {
-      if (p_x[i] == p_x[i]) p_x[i] = std::sqrt(p_x[i]);
+      p_x[i] = (p_x[i] == p_x[i]) ? std::sqrt(p_x[i]) : p_x[i];
     }
   }
   Rf_unprotect(1);
@@ -596,9 +594,10 @@ SEXP cpp_set_round(SEXP x, SEXP digits){
           if ( (p_x[i] == p_x[i] && p_digits[digitsi] != NA_INTEGER) ){
             double tempx = p_x[i];
             int tempdig = p_digits[digitsi];
-            tempx *= std::pow(10.0, tempdig);
+            double mfactor = std::pow(10, tempdig);
+            tempx *= mfactor;
             tempx = round_nearest_even(tempx);
-            tempx *= std::pow(10.0, -(tempdig));
+            tempx /= mfactor;
             p_x[i] = tempx;
           } else {
             p_x[i] = NA_REAL;
@@ -611,9 +610,10 @@ SEXP cpp_set_round(SEXP x, SEXP digits){
           if ( (p_x[i] == p_x[i] && p_digits[digitsi] != NA_INTEGER) ){
             double tempx = p_x[i];
             int tempdig = p_digits[digitsi];
-            tempx *= std::pow(10.0, tempdig);
+            double mfactor = std::pow(10, tempdig);
+            tempx *= mfactor;
             tempx = round_nearest_even(tempx);
-            tempx *= std::pow(10.0, -(tempdig));
+            tempx /= mfactor;
             p_x[i] = tempx;
           } else {
             p_x[i] = NA_REAL;
@@ -632,9 +632,10 @@ SEXP cpp_set_round(SEXP x, SEXP digits){
           if ( (p_x[i] == p_x[i] && p_digits[digitsi] == p_digits[digitsi]) ){
             double tempx = p_x[i];
             int tempdig = p_digits[digitsi];
-            tempx *= std::pow(10, tempdig);
+            double mfactor = std::pow(10, tempdig);
+            tempx *= mfactor;
             tempx = round_nearest_even(tempx);
-            tempx *= std::pow(10, -(tempdig));
+            tempx /= mfactor;
             p_x[i] = tempx;
           } else {
             p_x[i] = NA_REAL;
@@ -647,9 +648,10 @@ SEXP cpp_set_round(SEXP x, SEXP digits){
           if ( (p_x[i] == p_x[i] && p_digits[digitsi] == p_digits[digitsi]) ){
             double tempx = p_x[i];
             int tempdig = p_digits[digitsi];
-            tempx *= std::pow(10, tempdig);
+            double mfactor = std::pow(10, tempdig);
+            tempx *= mfactor;
             tempx = round_nearest_even(tempx);
-            tempx *= std::pow(10, -(tempdig));
+            tempx /= mfactor;
             p_x[i] = tempx;
           } else {
             p_x[i] = NA_REAL;
