@@ -1,6 +1,4 @@
 #include "cheapr_cpp.h"
-#include <cpp11.hpp>
-#include <Rinternals.h>
 
 int int_div(int x, int y){
   return x / y;
@@ -180,6 +178,11 @@ SEXP r_address(SEXP x) {
   return Rf_mkChar(buf);
 }
 
+[[cpp11::register]]
+SEXP r_copy(SEXP x){
+  return Rf_duplicate(x);
+}
+
 // Potentially useful for rolling calculations
 // Computes the rolling number of true values in a given
 // series of consecutive true values
